"""Ferda hooks implementation."""

from typing import Any, Dict, Iterable, Tuple

import ferda

from ferda_auction.settings import SETTINGS

_PERMISSIONS = (
    ("ferda_auction.can_view", "Can view auction module"),
    ("ferda_auction.can_view_all", "Can view confidential auction information"),
    ("ferda_auction.can_edit_auction", "Can edit auction"),
    ("ferda_auction.can_view_ban", "Can view auction ban"),
    ("ferda_auction.can_edit_ban", "Can edit auction ban"),
)


@ferda.hookimpl
def create_permissions() -> Iterable[Tuple[str, str]]:
    """Create ferda_auction permissions."""
    return _PERMISSIONS


@ferda.hookimpl
def show_settings() -> Dict[str, Any]:
    """Return context variables with ferda auction settings."""
    context = {
        "auction": {
            "api_url": SETTINGS.api_url,
        }
    }
    return context
